netapp_ontap.models.anti_ransomware_volume_workload API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.anti_ransomware_volume_workload`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class AntiRansomwareVolumeWorkloadSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the AntiRansomwareVolumeWorkload object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `file_extension_types_count: Size GET`

    Count of types of file extensions observed in the volume.

    Example: 3

  `file_extensions_observed: List[str] GET`

    File extensions observed in the volume.

    Example: ["pdf","jpeg","txt"]

  `historical_statistics: AntiRansomwareVolumeWorkloadHistoricalStatistics GET`

    Typical usage values of volume workload.

  `newly_observed_file_extensions: List[AntiRansomwareVolumeWorkloadNewlyObservedFileExtensions] GET`

    New file extensions observed in the volume during surge.

  `surge_statistics: AntiRansomwareVolumeWorkloadSurgeStatistics GET`

    Usage values of the volume's workload during surge.

  `surge_usage: AntiRansomwareVolumeWorkloadSurgeUsage GET`

    Usage values of the volume's workload during surge. This object is no longer supported use surge_statistics instead.

  `typical_usage: AntiRansomwareVolumeTypicalUsage GET`

    Typical usage values of volume workload. This object is no longer supported use historical_statistics instead.